==> openshift-model-operatorhub-5.12.3-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/SubscriptionBuilder.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class SubscriptionBuilder extends io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionFluentImpl<io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operatorhub.v1alpha1.Subscription,io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionBuilder>{
  public SubscriptionBuilder() {
    this(false);
  }
  public SubscriptionBuilder(java.lang.Boolean validationEnabled) {
    this(new Subscription(), validationEnabled);
  }
  public SubscriptionBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionFluent<?> fluent) {
    this(fluent, false);
  }
  public SubscriptionBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new Subscription(), validationEnabled);
  }
  public SubscriptionBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionFluent<?> fluent,io.fabric8.openshift.api.model.operatorhub.v1alpha1.Subscription instance) {
    this(fluent, instance, false);
  }
  public SubscriptionBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionFluent<?> fluent,io.fabric8.openshift.api.model.operatorhub.v1alpha1.Subscription instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public SubscriptionBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.Subscription instance) {
    this(instance,false);
  }
  public SubscriptionBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.Subscription instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.Subscription build() {
    Subscription buildable = new Subscription(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SubscriptionBuilder that = (SubscriptionBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-operatorhub-6.2.0-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/SubscriptionBuilder.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class SubscriptionBuilder extends SubscriptionFluentImpl<SubscriptionBuilder> implements VisitableBuilder<Subscription,SubscriptionBuilder>{
  public SubscriptionBuilder() {
    this(false);
  }
  public SubscriptionBuilder(Boolean validationEnabled) {
    this(new Subscription(), validationEnabled);
  }
  public SubscriptionBuilder(SubscriptionFluent<?> fluent) {
    this(fluent, false);
  }
  public SubscriptionBuilder(SubscriptionFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new Subscription(), validationEnabled);
  }
  public SubscriptionBuilder(SubscriptionFluent<?> fluent,Subscription instance) {
    this(fluent, instance, false);
  }
  public SubscriptionBuilder(SubscriptionFluent<?> fluent,Subscription instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public SubscriptionBuilder(Subscription instance) {
    this(instance,false);
  }
  public SubscriptionBuilder(Subscription instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  SubscriptionFluent<?> fluent;
  Boolean validationEnabled;
  public Subscription build() {
    Subscription buildable = new Subscription(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
